@@ -9,6 +9,7 @@
 #' @import XML
 #' @import httr
 #' @import jsonlite
+#' @import keyring
 #' @export
 #' @keywords ISO metadata element
 #' @return Object of \code{\link{R6Class}} for modelling an ISO Metadata Element
@@ -55,7 +56,7 @@
 #'  \item{\code{decode(xml)}}{
 #'    Decodes a ISOMetadata* R6 object from XML representation
 #'  }
-#'  \item{\code{encode(addNS, validate, strict, inspire, resetSerialID, setSerialID, encoding)}}{
+#'  \item{\code{encode(addNS, validate, strict, inspire, inspireValidator, resetSerialID, setSerialID, encoding)}}{
 #'    Encodes a ISOMetadata* R6 object to XML representation. By default, namespace
 #'    definition will be added to XML root (\code{addNS = TRUE}), and validation
 #'    of object will be performed (\code{validate = TRUE}) prior to its XML encoding.
@@ -67,13 +68,19 @@
 #'    associated to XML elements, such as GML objects, default value is \code{TRUE} 
 #'    (recommended value).
 #'    Setting \code{inspire} to TRUE (default FALSE), the metadata will be checked with
-#'    the INSPIRE metadata validator (online web-service provided by INSPIRE).
+#'    the INSPIRE metadata validator (online web-service provided by INSPIRE). To check 
+#'    metadata with the INSPIRE metadata validator, setting an INSPIRE metadata validator 
+#'    is now required, and should be specified with the \code{inspireValidator}. See 
+#'    \code{\link{INSPIREMetadataValidator}} for more details
 #'  }
-#'  \item{\code{validate(xml, strict, inspire)}}{
+#'  \item{\code{validate(xml, strict, inspire, inspireValidator)}}{
 #'    Validates the encoded XML against ISO 19139 XML schemas. If \code{strict} is
 #'    \code{TRUE}, a error will be raised. Default is \code{FALSE}.
 #'    Setting \code{inspire} to\code{TRUE} (default \code{FALSE}), the metadata will be 
 #'    checked with the INSPIRE metadata validator (online web-service provided by INSPIRE).
+#'    To check metadata with the INSPIRE metadata validator, setting an INSPIRE metadata validator 
+#'    is now required, and should be specified with the \code{inspireValidator}. See 
+#'    \code{\link{INSPIREMetadataValidator}} for more details
 #'  }
 #'  \item{\code{save(file, ...)}}{
 #'    Saves the current metadata object XML representation to a file. This utility
@@ -646,7 +653,7 @@ ISOAbstractObject <- R6Class("ISOAbstractObject",
     },
     
     #encode
-    encode = function(addNS = TRUE, validate = TRUE, strict = FALSE, inspire = FALSE,
+    encode = function(addNS = TRUE, validate = TRUE, strict = FALSE, inspire = FALSE, inspireValidator = NULL,
                       resetSerialID = TRUE, setSerialID = TRUE,
                       encoding = "UTF-8"){
       
@@ -968,13 +975,17 @@ ISOAbstractObject <- R6Class("ISOAbstractObject",
       #validation vs. ISO 19139 XML schemas + eventually INSPIRE
       compliant <- NA
       if(validate){
-        compliant <- self$validate(xml = out, strict = strict, inspire = inspire)
+        compliant <- self$validate(xml = out, strict = strict, inspire = inspire, inspireValidator = inspireValidator)
       }
       if(self$isDocument()){
         if(!inspire){
           header_comments <- private$xmlComments(compliant)
         }else{
-          header_comments <- private$xmlComments(compliant$ISO, compliant$INSPIRE)
+          if(is.list(compliant)){
+            header_comments <- private$xmlComments(compliant$ISO, compliant$INSPIRE)
+          }else{
+            header_comments <- private$xmlComments(compliant)
+          }
         }
         #process XML comments
         for(comment in header_comments){
@@ -996,7 +1007,7 @@ ISOAbstractObject <- R6Class("ISOAbstractObject",
     },
     
     #validate
-    validate = function(xml = NULL, strict = FALSE, inspire = FALSE){
+    validate = function(xml = NULL, strict = FALSE, inspire = FALSE, inspireValidator = NULL){
       
       #xml
       schemaNamespaceId <- NULL
@@ -1036,12 +1047,15 @@ ISOAbstractObject <- R6Class("ISOAbstractObject",
       }
       
       if(inspire){
-        inspireValidator <- INSPIREMetadataValidator$new()
-        inspireReport <- inspireValidator$getValidationReport(obj = self)
-        isValid <- list(
-          ISO = isValid,
-          INSPIRE = inspireReport
-        )
+        if(!is.null(inspireValidator) && is(inspireValidator, "INSPIREMetadataValidator")){
+          inspireReport <- inspireValidator$getValidationReport(obj = self)
+          isValid <- list(
+            ISO = isValid,
+            INSPIRE = inspireReport
+          )
+        }else{
+          self$WARN("No INSPIRE Metadata validator set, aborting INSPIRE metadata validation!")
+        }
       }
       
       return(isValid)
