@@ -31,8 +31,8 @@ ISOBaseDecimal <- R6Class("ISOBaseDecimal",
      
      #decimal places
      decimalplaces = function(x) {
-        if ((x %% 1) != 0) {
-           nchar(strsplit(sub('0+$', '', as.character(x)), ".", fixed=TRUE)[[1]][[2]])
+        if (abs(x - round(x)) > .Machine$double.eps^0.5) {
+          nchar(strsplit(sub('0+$', '', as.character(x)), ".", fixed = TRUE)[[1]][[2]])
         } else {
            return(0)
         }
