@@ -280,7 +280,7 @@ test_that("encoding/decoding",{
   result <- ISOConformanceResult$new()
   spec <- ISOCitation$new()
   spec$setTitle("specification title")
-  spec$setAlternateTitle("specification alternate title")
+  spec$addAlternateTitle("specification alternate title")
   d <- ISODate$new()
   d$setDate(ISOdate(2015, 1, 1, 1))
   d$setDateType("publication")
@@ -568,7 +568,7 @@ test_that("encoding/decoding",{
   result <- ISOConformanceResult$new()
   spec <- ISOCitation$new()
   spec$setTitle("specification title")
-  spec$setAlternateTitle("specification alternate title")
+  spec$addAlternateTitle("specification alternate title")
   d <- ISODate$new()
   d$setDate(ISOdate(2015, 1, 1, 1))
   d$setDateType("publication")
@@ -1214,7 +1214,7 @@ test_that("encoding/decoding - i18n",{
       RU="название спецификации",
       ZH="规范的标题"
     ))
-  spec$setAlternateTitle(
+  spec$addAlternateTitle(
     "specification alternate title",
     locales = list(
       EN="specification alternate title",
